#!/bin/bash

source "${SSDT_SCRIPTS:-$(dirname "${BASH_SOURCE[0]}")}/.functions.sh"

sourceFile=${1?must provide backup file to be restored}

if [ -z "$1" ]
then
  echo "Usage: `basename $0` {backup file to restore}"
  echo " must specify the name of the file to restore.  Assumed to be in format:"
  echo "     {entityId}-ess-db.{timestamp}.backup.gz  "
  exit $E_NOARGS
fi

function prop {
   grep "${1}" .env/ess-shared.properties|cut -d'=' -f2
}

entityId=$(prop 'entityId' | tr -d '"')
dbContainerName="$entityId-ess-db"
appContainerName="$entityId-ess-app"
target="essdb"

echo
echo "Preparing to restore"
echo "--------------------"
echo "   file: $sourceFile"
echo "   to    $dbContainerName database: $target"
echo " "
echo "WARNING:  This operation will DELETE and replace any exising database"
echo " "

read -e -p "Continue? <y/N> " answer
case $answer in
     y | Y | yes | YES ) answer="y";;
     n | N | no | NO ) answer="n";;
     *) answer="n"
esac

if [ "$answer" == "y" ]
then
  echo "stopping application service $appContainerName"
  docker stop $appContainerName

  echo "copy backup file to database container"
  docker cp ${sourceFile} ${dbContainerName}:/tmp/restore.backup.gz

  echo "starting database restore"
  docker exec -t -u postgres $dbContainerName sh -c "gunzip -f /tmp/restore.backup.gz -c | psql"

fi
